import sys
import os

def main():
    for i in sys.argv[1:]:
        if os.path.exists(i) == False:
            print(f"rmdir: {i}: No such file or directory")
            continue
        if len(os.listdir(i)) > 0:
            print(f"rmdir: {i}: Directory not empty")
            continue
        os.rmdir(i)

if __name__ == "__main__":
    main()


import sys
import os

def main():
    for i in sys.argv[1:]:
        if os.path.exists(i) == True:
            print(f"mkdir: {i}: File exists")
            continue
        os.mkdir(i)

if __name__ == "__main__":
    main()


import sys
import os

def main():
    if len(sys.argv) < 2:
        sys.argv.append(".")
    for i in sys.argv[1:]:
        if os.path.exists(i) == False:
            print(f"ls: {i}: No such file or directory")
            continue
        if os.path.isfile(i) == True:
            print(i)
            continue
        lis = os.listdir(i)
        if len(sys.argv[1:]) > 1:
            print(i + ":")
        for j in lis:
            print(j)
        if len(sys.argv[1:]) > 1:
            print("\n")

if __name__ == "__main__":
    main()


import sys
import os

def main():
    if os.path.isdir(sys.argv[-1]) == False and len(sys.argv[1:-1]) > 1:
        print(f"mv: {sys.argv[-1]} is not a directory")
        exit()
    for i in sys.argv[1:-1]:
        if os.path.isfile(sys.argv[-1]):
            os.remove(sys.argv[-1])
            os.rename(i, sys.argv[-1])
        else:
            os.rename(i, sys.argv[-1])

if __name__ == "__main__":
    main()


import sys
import os

def main():
    for i in sys.argv[1:]:
        if os.path.exists(i) == False:
            print(f"cat: {i}: No such file or directory")
            continue
        if os.path.isdir(i) == True:
            print(f"cat: {i}: Is a directory")
            continue
        with open(i, "rb") as f:
            for byte in f.read():
                print(chr(byte), end = "")

if __name__ == "__main__":
    main()


import sys
import os

def rmdir(dirname):
    lis = os.listdir(dirname)
    for i in lis:
        if os.path.isfile(os.path.join(dirname, i)) == True:
            os.remove(os.path.join(dirname, i))
        elif len(os.listdir(os.path.join(dirname, i))) == 0:
            """空文件夹"""
            os.rmdir(os.path.join(dirname, i))
        else:
            rmdir(os.path.join(dirname, i))
    os.rmdir(dirname)

def main():
    for i in sys.argv[1:]:
        if i[0] == "-":
            continue
        if os.path.exists(i) == False:
            print(f"rm: {i}: No such file or directory")
            continue
        if os.path.isdir(i) == True:
            if ("-r" in sys.argv[1:]) == False:
                print(f"rm: {i}: is a directory")
                continue
            else:
                rmdir(i)
                continue
        os.remove(i)

if __name__ == "__main__":
    main()


from setuptools import setup, find_packages

setup(
    name = "coreutils-python",
    version = "0.0.1",
    packages = find_packages(),
    entry_points = {
        "console_scripts": ["ls = coreutils.ls:main",
                            "rm = coreutils.rm:main",
                            "cp = coreutils.cp:main",
                            "mv = coreutils.mv:main",
                            "cat = coreutils.cat:main",
                            "echo = coreutils.echo:main",
                            "mkdir = coreutils.mkdir:main",
                            "rmdir = coreutils.rmdir:main"]
    }
)



import sys
import os
import shutil

def main():
    if os.path.isdir(sys.argv[-1]) == False and len(sys.argv[1:-1]) > 1:
        print(f"cp: {sys.argv[-1]} is not a directory")
        exit()
    for i in sys.argv[1:-1]:
        shutil.copy(i, sys.argv[-1])

if __name__ == "__main__":
    main()